@@ -14,14 +14,14 @@
 */
 
 /**
- * Copyright 2003 LUT. .
+ * Copyright 2003-2011 LUT. .
  *
  * @name PeerHoodImpl.cc
  * @memo Implementation of the CPeerHoodImpl class.
  *
- * @version 0.3
+ * @version 0.31
  * date     19.05.2003
- * change   28.04.2010
+ * change   19.04.2011
  */
 
 #include <stdio.h>
@@ -126,6 +126,8 @@ CPeerHoodImpl::CPeerHoodImpl(CBasicCallback* aCallback)
   LoadPlugins();
   iEngine->LoadConnections(iPid);
   iEngine->StartListening();
+  
+  iRTI = PHRTI::GetInstance();
 }
 
 
@@ -139,6 +141,12 @@ CPeerHoodImpl::CPeerHoodImpl(CBasicCallback* aCallback)
  */
 CPeerHoodImpl::~CPeerHoodImpl()
 {
+	if(iRTI)
+	{
+		delete iRTI;
+		iRTI = NULL;
+	}
+	
   delete iEngine; // stops the listening thread on engine!
 
   if (iConnected) close(iDaemonSocket);
@@ -1614,7 +1622,7 @@ void CPeerHoodImpl::RoamingThread()
 		serviceFound = false;
 
 		TCommand pdu;
-		TDeviceList* retval;
+		TDeviceList* retval_list;
 		char *buffer = NULL;
 		CLibDevice* temp;
 
@@ -1646,13 +1654,13 @@ void CPeerHoodImpl::RoamingThread()
 		  break;
 		}
 
-		retval = new TDeviceList;
+		retval_list = new TDeviceList;
 		int length = 0;
 		// read all devices
 		for (int j = 0;j < numberOfDevices;j++) {
 		  if (!read(daemonSocket, &length, sizeof(length))) {
 		    ERR("CPeerHoodImpl::RoamingThread : reading length of device failed");
-		    delete retval;
+		    delete retval_list;
 		    iRoaming = false;
 		    break;
 		  }
@@ -1662,17 +1670,17 @@ void CPeerHoodImpl::RoamingThread()
 		  if (!read(daemonSocket, buffer, length)) {
 		    ERR("CPeerHoodImpl::RoamingThread : reading device failed");
 		    delete[] buffer;
-		    delete retval;
+		    delete retval_list;
 		    iRoaming = false;
 		    break;
 		  }
 
 		  temp = new CLibDevice(buffer);
-		  retval->Add(temp);
+		  retval_list->Add(temp);
 		  delete[] buffer;
 		}
 
-		for (TDeviceIterator j = retval->Begin();j != retval->End();++j) {
+		for (TDeviceIterator j = retval_list->Begin();j != retval_list->End();++j) {
 		  if(((*j)->GetName().compare(i->iDeviceName) == 0) && ((*j)->GetChecksum() == i->iChecksum) && ((*j)->GetPrototype().compare(i->iPrototype) != 0))
 		    {
 		      services = (*j)->GetServiceListL();
@@ -1691,7 +1699,7 @@ void CPeerHoodImpl::RoamingThread()
 		    }
 		}
 		// delete temp;
-		delete retval;
+		delete retval_list;
 		state = 1;
 		break;
 	      }//case 0:
