@@ -91,10 +91,11 @@ CDaemon::CDaemon()
 
 	// TODO change to use UUID - which must be saved
 	// Caclulate checksum
-  iChecksum = CalculateChecksum();
+  //iChecksum = CalculateChecksum();
   
   // Could not calculate
-  if(iChecksum == 0) iChecksum = (long)getpid() ^ gethostid();
+  //if(iChecksum == 0) iChecksum = (long)getpid() ^ gethostid();
+  iChecksum = (long)getpid() ^ gethostid();
   DBG("Checksum = %u",iChecksum);
   iChecksum = htonl(iChecksum);
 
